==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/TrainRelocationPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.infrastructure.component.BezierTrackPointLocation;
import java.util.UUID;
import java.util.function.BiConsumer;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_3244;
import net.minecraft.class_4844;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TrainRelocationPacket(
    UUID trainId, class_2338 pos, class_243 lookAngle, int entityId, boolean direction, BezierTrackPointLocation hoveredBezier
) implements C2SPacket {
    public static final class_9139<class_9129, TrainRelocationPacket> CODEC = class_9139.method_58025(
        class_4844.field_48453,
        TrainRelocationPacket::trainId,
        class_2338.field_48404,
        TrainRelocationPacket::pos,
        class_243.field_52694,
        TrainRelocationPacket::lookAngle,
        class_9135.field_49675,
        TrainRelocationPacket::entityId,
        class_9135.field_48547,
        TrainRelocationPacket::direction,
        CatnipStreamCodecBuilders.nullable(BezierTrackPointLocation.STREAM_CODEC),
        TrainRelocationPacket::hoveredBezier,
        TrainRelocationPacket::new
    );

    @Override
    public class_9145<TrainRelocationPacket> method_65080() {
        return AllPackets.RELOCATE_TRAIN;
    }

    @Override
    public BiConsumer<class_3244, TrainRelocationPacket> callback() {
        return AllHandle::onTrainRelocation;
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/TrainRelocationPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.infrastructure.component.BezierTrackPointLocation;
import java.util.UUID;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_4844;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TrainRelocationPacket(
    UUID trainId, class_2338 pos, class_243 lookAngle, int entityId, boolean direction, BezierTrackPointLocation hoveredBezier
) implements class_2596<class_2792> {
    public static final class_9139<class_9129, TrainRelocationPacket> CODEC = class_9139.method_58025(
        class_4844.field_48453,
        TrainRelocationPacket::trainId,
        class_2338.field_48404,
        TrainRelocationPacket::pos,
        class_243.field_52694,
        TrainRelocationPacket::lookAngle,
        class_9135.field_49675,
        TrainRelocationPacket::entityId,
        class_9135.field_48547,
        TrainRelocationPacket::direction,
        CatnipStreamCodecBuilders.nullable(BezierTrackPointLocation.STREAM_CODEC),
        TrainRelocationPacket::hoveredBezier,
        TrainRelocationPacket::new
    );

    @Override
    public void apply(class_2792 listener) {
        AllHandle.onTrainRelocation((class_3244) listener, this);
    }

    @Override
    public class_9145<TrainRelocationPacket> method_65080() {
        return AllPackets.RELOCATE_TRAIN;
    }
}
